"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processTableOfContents = void 0;
const crypto_1 = require("crypto");
// Hash 생성 시 사용할 캐시
const hashCache = new Map();
const processTableOfContents = async (block, tableOfContents) => {
    if (["heading_1", "heading_2", "heading_3"].includes(block.type) &&
        block[block.type]?.rich_text?.length > 0) {
        const plainText = block[block.type]?.rich_text?.[0]?.plain_text || "";
        // 이미 처리된 플레인텍스트인지 확인
        let hash;
        if (hashCache.has(plainText)) {
            hash = hashCache.get(plainText);
        }
        else {
            hash = `link-${plainText
                .replace(/[^a-zA-Z0-9가-힣\s-_]/g, "")
                .trim()
                .replace(/\s+/g, "-")
                .toLowerCase()}-${(0, crypto_1.randomUUID)().substring(0, 4)}`;
            hashCache.set(plainText, hash);
        }
        block.hash = hash;
        // 중복 체크 - 동일한 hash가 이미 존재하는지 확인
        const existingTocIndex = tableOfContents.findIndex((toc) => toc.hash === hash);
        if (existingTocIndex === -1) {
            tableOfContents.push({
                type: block.type,
                hash,
                title: plainText,
            });
        }
    }
};
exports.processTableOfContents = processTableOfContents;
